@@ -20,16 +20,14 @@ class Config:
     def __contains__(self):
         pass
 
-    def get(self, *args):
-        pass
+    def get(self, key: str):
+        return self.__dict__[key]
 
     def Items(self):
-        pass
+        return list(self.__dict__.items())
 
-    def keys(self):
-        pass
+    def keys(self) -> list:
+        return list(self.__dict__.keys())
 
-    def __getattr__(self, name):
-        value = "Value for %s" % name
-        setattr(self, name, value)
-        return value
+    def values(self) -> list:
+        return list(self.__dict__.values())
