@@ -70,7 +70,7 @@ class Table(Media):
         path = self.get_path(key_name, value_type)
         logger.debug(f"file upload[table] : local_path=[{local_path}], root_path=[{root_path}], path=[{path}]")
 
-        interface.upload_file(upload_type="RUN", local_path=local_path, root_path=root_path, path=path, run_id=run.run_id, artifact_id=0, last_file_yn="Y",teamName="", expName="", artifact_name="", artifact_type="", artifact_digest="", entry_digest=digest, entry_list=[], file_index=0)
+        interface.upload_file(upload_type="RUN", local_path=local_path, root_path=root_path, path=path, run_id=run.run_id, artifact_id=0, last_file_yn="Y",teamName=run.team_name, expName=run.exp_name, run_name= run.run_name,artifact_name="", artifact_type="", artifact_digest="", entry_digest=digest, entry_list=[], file_index=0)
 
     def get_root_path(self, run_id: int) -> str:
         return os.path.join(str(run_id), "media")
