@@ -2,10 +2,13 @@ import logging
 from typing import Dict
 
 from deepdriver.sdk.data_types.run import set_run, Run
+
 from deepdriver.sdk.interface import interface
 
 from deepdriver import logger
 from deepdriver import util
+import deepdriver
+
 
 # 실행과 실험환경을 만드는 함수
 @util.login_required
@@ -19,4 +22,8 @@ def init(exp_name: str="", team_name: str="", run_name: str="", config: Dict=Non
         f"Run URL={rsp['runUrl']}"
     )
     set_run(run)
+
+    for key, value in config.items():
+        setattr(deepdriver.config, key, value)
+
     return run
